package main

import (
	"encoding/json"
	"github.com/aarongao/tools"
	"github.com/gin-gonic/gin"
	"gopkg.in/mgo.v2"
	"letu/Api"
	"letu/Config"
	"letu/DB"
	"letu/Lib/Ws"
	"os"
)

// @APIVersion 1.0.0
// @APITitle 乐游图后端接口文档
// @BasePath https://letu.api.imagchina.com
func main() {

	// 读取配置文件
	dir, _ := os.Getwd()
	//println(dir)
	file, _ := os.Open(dir + "/Config/config.json")
	defer file.Close()
	decoder := json.NewDecoder(file)
	conf := Config.Config{}
	err := decoder.Decode(&conf)
	tools.CheckError(err)

	// 连接数据库
	DB.DBSession, err = mgo.Dial(conf.DbPath)
	defer DB.DBSession.Close()
	//设置模式
	DB.DBSession.SetMode(mgo.Monotonic, true)
	//获取文档集
	DB.DB = DB.DBSession.DB("LeYouTu")
	DB.CItem = DB.DB.C("Item")
	DB.CComplaint = DB.DB.C("Complaint")
	DB.CInvestigation = DB.DB.C("Investigation")
	DB.CMember = DB.DB.C("Member")
	DB.CCommodity = DB.DB.C("Commodity")
	DB.CTags = DB.DB.C("Tags")
	DB.CScenic = DB.DB.C("Scenic")
	DB.CLine = DB.DB.C("Line")
	DB.CAccessLog = DB.DB.C("AccessLog")

	r := gin.Default()
	//r.Static("/.well-known", "./.well-known/")
	r.Static("/tiles", dir+"/tiles")
	r.GET("/AllItems", Api.AllItems)
	r.GET("/AllCommodity", Api.AllCommodity)
	r.GET("/AllLine", Api.AllLine)
	r.GET("/ItemInfo", Api.ItemInfo)
	r.GET("/CommodityInfo", Api.CommodityInfo)
	r.POST("/CreateComplaint", Api.CreateComplaint)
	r.POST("/CreateUser", Api.CreateUser)
	r.POST("/LoginUser", Api.LoginUser)
	r.GET("/UserInfo", Api.UserInfo)
	r.GET("/ScenicInfo", Api.ScenicInfo)
	r.GET("/LineInfo", Api.LineInfo)
	r.GET("/AllTag", Api.AllTag)
	r.POST("/Upload", Api.Upload)
	r.POST("/UpdateItem", Api.UpdateItem)
	r.POST("/UpdateCommodity", Api.UpdateCommodity)
	r.POST("/UpdateLine", Api.UpdateLine)
	r.POST("/UpdateScenic", Api.UpdateScenic)
	r.POST("/UpdateItemTime", Api.UpdateItemTime)
	r.GET("/AllScenic", Api.AllScenic)
	r.POST("/AccessLog", Api.AccessLog)
	r.GET("/AccessLog", Api.AccessLog)
	//r.GET("/ws", Api.WsPage)

	r.Static("/Upload", "./Upload")
	r.Static("/Console", "./Console")
	go Ws.Manager.Start()
	r.Run(":8080")
}
